# -*- coding: utf-8 -*-
'''
Advanced Power Locale
2010(c) Kirill Plyashkevich <ru.spirit@gmail.com>
'''

from advpowcommon.util.locale import Locale

class APLocale(Locale):

  def __init__(self):
    Locale.__init__(self)

  def initialize(self):
    self.text_domain = 'advanced-power'
    self.current_dict = {
      'item-battery_status': 'Battery',
      'item-battery_status_unknown': 'Unknown battery state',
      'item-battery_status_very_low': 'Battery level is very low',
      'item-battery_status_full': 'Battery is full',
      'item-battery_status_charging': 'Battery is charging',
      'item-battery_status_charger_disconn': 'Charger disconnected',
      'item-timeleft':  'Time left',
      'item-settings-translators': 'Translators',
      'item-settings-about': 'About',
      'unknown': 'unknown'
    }

aplocale_singleton = APLocale()
def get_locale(): return aplocale_singleton